hstrat.hstrat.stratum\_retention\_condemners.StratumRetentionCondemnerFixedResolution
=====================================================================================

.. currentmodule:: hstrat.hstrat.stratum_retention_condemners

.. autoclass:: StratumRetentionCondemnerFixedResolution

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~StratumRetentionCondemnerFixedResolution.CalcMrcaUncertaintyUpperBound
      ~StratumRetentionCondemnerFixedResolution.CalcNumStrataRetainedExact
      ~StratumRetentionCondemnerFixedResolution.CalcNumStrataRetainedUpperBound
      ~StratumRetentionCondemnerFixedResolution.CalcRankAtColumnIndex
      ~StratumRetentionCondemnerFixedResolution.__init__
   
   

   
   
   